Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(392)

Unified Diff: utils/compiler/buildbot.py

Issue 10453050: We're building the SDK -- not frog. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: utils/compiler/buildbot.py
diff --git a/utils/compiler/buildbot.py b/utils/compiler/buildbot.py
index cde195c0f7d588d5c654492ac15757505f6719a2..2b4820a62b9d5e2e597722a9649eddff2c527988 100644
--- a/utils/compiler/buildbot.py
+++ b/utils/compiler/buildbot.py
@@ -143,10 +143,9 @@ def TestStep(name, mode, system, compiler, runtime, targets, flags):
return exit_code
-def BuildCompiler(compiler, mode, system):
- """ build the compiler.
+def BuildSDK(mode, system):
+ """ build the SDK.
Args:
- - compiler: either 'dart2js' or 'frog'
- mode: either 'debug' or 'release'
- system: either 'linux', 'mac', or 'win7'
"""
@@ -164,7 +163,7 @@ def BuildCompiler(compiler, mode, system):
os.chdir(DART_PATH)
- print '@@@BUILD_STEP build frog@@@'
+ print '@@@BUILD_STEP build sdk@@@'
args = [sys.executable, './tools/build.py', '--mode=' + mode, 'create_sdk']
print 'running %s' % (' '.join(args))
@@ -291,7 +290,7 @@ def main():
if compiler is None:
return 1
- status = BuildCompiler(compiler, mode, system)
+ status = BuildSDK(mode, system)
if status != 0:
print '@@@STEP_FAILURE@@@'
return status
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698